@@ -2,7 +2,7 @@
  * Caja-Actions
  * A Caja extension which offers configurable context menu actions.
  *
- * Copyright (C) 2005 The MATE Foundation
+ * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
  * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
@@ -92,7 +92,7 @@ struct _CactAssistantImportPrivate {
 	GtkTreeView *duplicates_listview;
 	NAIOption   *mode;
 	GList       *results;
-	GList       *overriden;
+	GList       *overridden;
 };
 
 static const gchar        *st_xmlui_filename = PKGUIDIR "/cact-assistant-import.ui";
@@ -350,27 +350,6 @@ on_base_initialize_gtk( CactAssistantImport *dialog )
 	if( !dialog->private->dispose_has_run ){
 		g_debug( "%s: dialog=%p", thisfn, ( void * ) dialog );
 
-#if !GTK_CHECK_VERSION( 3,0,0 )
-		guint padder = 8;
-		GtkAssistant *assistant = GTK_ASSISTANT( base_window_get_gtk_toplevel( BASE_WINDOW( dialog )));
-		/* selecting files */
-		GtkWidget *page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_FILES_SELECTION );
-		GtkWidget *container = find_widget_from_page( page, "p1-l2-alignment1" );
-		g_object_set( G_OBJECT( container ), "top_padding", padder, NULL );
-		/* managing duplicates */
-		page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_DUPLICATES );
-		container = find_widget_from_page( page, "p2-l2-alignment1" );
-		g_object_set( G_OBJECT( container ), "border_width", padder, NULL );
-		/* summary */
-		page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_CONFIRM );
-		container = find_widget_from_page( page, "p3-l2-alignment1" );
-		g_object_set( G_OBJECT( container ), "border_width", padder, NULL );
-		/* import is done */
-		page = gtk_assistant_get_nth_page( assistant, ASSIST_PAGE_DONE );
-		container = find_widget_from_page( page, "p4-l2-alignment1" );
-		g_object_set( G_OBJECT( container ), "border_width", padder, NULL );
-#endif
-
 		create_duplicates_treeview_model( dialog );
 	}
 }
@@ -592,16 +571,6 @@ prepare_confirm( CactAssistantImport *window, GtkAssistant *assistant, GtkWidget
 	g_debug( "%s: window=%p, assistant=%p, page=%p",
 			thisfn, ( void * ) window, ( void * ) assistant, ( void * ) page );
 
-#if !GTK_CHECK_VERSION( 3,0,0 )
-	/* Note that, at least, in Gtk 2.20 (Ubuntu 10) and 2.22 (Fedora 14), GtkLabel
-	 * queues its resize (when the text is being set), but the actual resize does
-	 * not happen immediately - We have to wait until Gtk 3.0, most probably due
-	 * to the new width-for-height and height-for-width features...
-	 */
-	GtkWidget *vbox = find_widget_from_page( page, "p3-ConfirmVBox" );
-	gtk_container_set_resize_mode( GTK_CONTAINER( vbox ), GTK_RESIZE_IMMEDIATE );
-#endif
-
 	/* adding list of uris to import
 	 */
 	text = NULL;
@@ -654,7 +623,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 	NAImporterParms importer_parms;
 	BaseWindow *main_window;
 	GList *import_results, *it;
-	GList *insertable_items, *overriden_items;
+	GList *insertable_items, *overridden_items;
 	NAImporterResult *result;
 	CactApplication *application;
 	NAUpdater *updater;
@@ -678,7 +647,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 	import_results = na_importer_import_from_uris( NA_PIVOT( updater ), &importer_parms );
 
 	insertable_items = NULL;
-	overriden_items = NULL;
+	overridden_items = NULL;
 
 	for( it = import_results ; it ; it = it->next ){
 		result = ( NAImporterResult * ) it->data;
@@ -688,7 +657,7 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 				insertable_items = g_list_prepend( insertable_items, result->imported );
 
 			} else if( result->mode == IMPORTER_MODE_OVERRIDE ){
-				overriden_items = g_list_prepend( overriden_items, result->imported );
+				overridden_items = g_list_prepend( overridden_items, result->imported );
 			}
 		}
 	}
@@ -713,10 +682,10 @@ assistant_apply( BaseAssistant *wnd, GtkAssistant *assistant )
 	/* contrarily, the tree store may or not take a new reference on overriding
 	 * items, so do not release it here
 	 */
-	if( overriden_items ){
+	if( overridden_items ){
 		items_view = cact_main_window_get_items_view( CACT_MAIN_WINDOW( main_window ));
-		cact_tree_ieditable_set_items( CACT_TREE_IEDITABLE( items_view ), overriden_items );
-		window->private->overriden = overriden_items;
+		cact_tree_ieditable_set_items( CACT_TREE_IEDITABLE( items_view ), overridden_items );
+		window->private->overridden = overridden_items;
 	}
 }
 
@@ -767,15 +736,6 @@ prepare_importdone( CactAssistantImport *window, GtkAssistant *assistant, GtkWid
 	vbox = find_widget_from_page( page, "p4-SummaryVBox" );
 	g_return_if_fail( GTK_IS_BOX( vbox ));
 
-#if !GTK_CHECK_VERSION( 3,0,0 )
-	/* Note that, at least, in Gtk 2.20 (Ubuntu 10) and 2.22 (Fedora 14), GtkLabel
-	 * queues its resize (when the text is being set), but the actual resize does
-	 * not happen immediately - We have to wait until Gtk 3.0, most probably due
-	 * to the new width-for-height and height-for-width features...
-	 */
-	gtk_container_set_resize_mode( GTK_CONTAINER( vbox ), GTK_RESIZE_IMMEDIATE );
-#endif
-
 	/* for each uri
 	 * 	- display the uri
 	 *  - display a brief import log
@@ -786,11 +746,7 @@ prepare_importdone( CactAssistantImport *window, GtkAssistant *assistant, GtkWid
 
 		/* display the uri
 		 */
-#if GTK_CHECK_VERSION( 3,0,0 )
 		file_vbox = gtk_box_new( GTK_ORIENTATION_VERTICAL, 4 );
-#else
-		file_vbox = gtk_vbox_new( FALSE, 4 );
-#endif
 		gtk_box_pack_start( GTK_BOX( vbox ), file_vbox, FALSE, FALSE, 0 );
 
 		color = result->imported ? "blue" : "red";
@@ -845,8 +801,8 @@ prepare_importdone( CactAssistantImport *window, GtkAssistant *assistant, GtkWid
 
 	/* release here our reference on overriding items
 	 */
-	if( window->private->overriden ){
-		na_object_free_items( window->private->overriden );
+	if( window->private->overridden ){
+		na_object_free_items( window->private->overridden );
 	}
 
 	g_object_set( G_OBJECT( window ), BASE_PROP_WARN_ON_ESCAPE, FALSE, NULL );
