@@ -2,7 +2,7 @@
  * Caja-Actions
  * A Caja extension which offers configurable context menu actions.
  *
- * Copyright (C) 2005 The MATE Foundation
+ * Copyright (C) 2005 The GNOME Foundation
  * Copyright (C) 2006-2008 Frederic Ruaudel and others (see AUTHORS)
  * Copyright (C) 2009-2012 Pierre Wieser and others (see AUTHORS)
  *
@@ -304,13 +304,8 @@ cact_tree_model_dnd_imulti_drag_source_drag_data_get( EggTreeMultiDragSource *dr
 
 	selection_data_target = gtk_selection_data_get_target( selection_data );
 
-#if GTK_CHECK_VERSION( 2, 22, 0 )
 	context_suggested_action = gdk_drag_context_get_suggested_action( context );
 	context_selected_action = gdk_drag_context_get_selected_action( context );
-#else
-	context_suggested_action = context->suggested_action;
-	context_selected_action = context->action;
-#endif
 
 	atom_name = gdk_atom_name( selection_data_target );
 	g_debug( "%s: drag_source=%p (ref_count=%d), context=%p, suggested action=%d, selection_data=%p, rows=%p (count=%d), atom=%s",
@@ -501,11 +496,7 @@ cact_tree_model_dnd_on_drag_begin( GtkWidget *widget, GdkDragContext *context, B
 
 		cact_clipboard_dnd_clear( model->private->clipboard );
 
-#if GTK_CHECK_VERSION( 2, 22, 0 )
 		context_source_window = gdk_drag_context_get_source_window( context );
-#else
-		context_source_window = context->source_window;
-#endif
 
 		gdk_property_change(
 				context_source_window,
@@ -542,11 +533,7 @@ cact_tree_model_dnd_on_drag_end( GtkWidget *widget, GdkDragContext *context, Bas
 		cact_clipboard_dnd_drag_end( model->private->clipboard );
 		cact_clipboard_dnd_clear( model->private->clipboard );
 
-#if GTK_CHECK_VERSION( 2, 22, 0 )
 		context_source_window = gdk_drag_context_get_source_window( context );
-#else
-		context_source_window = context->source_window;
-#endif
 
 		gdk_property_delete( context_source_window, XDS_ATOM );
 	}
@@ -860,7 +847,7 @@ drop_uri_list( CactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	GList *import_results, *it;
 	guint count;
 	GSList *im;
-	GList *imported, *overriden;
+	GList *imported, *overridden;
 	const gchar *selection_data_data;
 	CactTreeView *view;
 	GSList *messages;
@@ -901,7 +888,7 @@ drop_uri_list( CactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	 * of all lines of messages, and the list of imported items
 	 */
 	imported = NULL;
-	overriden = NULL;
+	overridden = NULL;
 	messages = NULL;
 
 	for( it = import_results ; it ; it = it->next ){
@@ -916,7 +903,7 @@ drop_uri_list( CactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 				na_updater_check_item_writability_status( updater, result->imported );
 
 			} else if( result->mode == IMPORTER_MODE_OVERRIDE ){
-				overriden = g_list_prepend( overriden, result->imported );
+				overridden = g_list_prepend( overridden, result->imported );
 			}
 		}
 	}
@@ -955,16 +942,16 @@ drop_uri_list( CactTreeModel *model, GtkTreePath *dest, GtkSelectionData  *selec
 	/* override items if needed
 	 * they may safely be released after having updated the store
 	 */
-	if( overriden ){
-		na_object_dump_tree( overriden );
+	if( overridden ){
+		na_object_dump_tree( overridden );
 		view = cact_main_window_get_items_view( main_window );
-		cact_tree_ieditable_set_items( CACT_TREE_IEDITABLE( view ), overriden );
-		na_object_free_items( overriden );
+		cact_tree_ieditable_set_items( CACT_TREE_IEDITABLE( view ), overridden );
+		na_object_free_items( overridden );
 	}
 
 	drop_done = TRUE;
 	na_object_free_items( imported );
-	na_object_free_items( overriden );
+	na_object_free_items( overridden );
 	na_core_utils_slist_free( parms.uris );
 
 	for( it = import_results ; it ; it = it->next ){
@@ -1105,11 +1092,7 @@ get_xds_atom_value( GdkDragContext *context )
 	gint actual_length;
 	GdkWindow *context_source_window;
 
-#if GTK_CHECK_VERSION( 2, 22, 0 )
-		context_source_window = gdk_drag_context_get_source_window( context );
-#else
-		context_source_window = context->source_window;
-#endif
+	context_source_window = gdk_drag_context_get_source_window( context );
 
 	g_return_val_if_fail( context != NULL, NULL );
 	g_return_val_if_fail( context_source_window != NULL, NULL );
